import React, { useState, useMemo, useRef, useEffect } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import getcolumns from './columns';
import { doFetch } from '@/utils/doFetch';
import { useRequest } from "ahooks";
const Custom = () => {
    let actionRef = useRef();
    const [drawer, setdrawer] = useState({
        visible: false,
    });
    const { run, loading, runAsync } = useRequest(doFetch, {
        manual: true,
        onSuccess: (res, params) => {
            if (res?.code == "0000") {
                actionRef?.current?.reload();
                setdrawer((s) => ({
                    ...s,
                    visible: false,
                }));
            }
        },
    });

    const edit = (text, row, _, action) => {
        return (
            <PremButton
                key='edit'
                btn={{
                    size: 'small',
                    onClick: () => {
                        setdrawer((s) => ({
                            ...s,
                            visible: true,
                            item: row,
                            val: 'edit',
                            title: '编辑'
                        }));
                    },
                }}
            >
                编辑
            </PremButton>
        );
    };

    const remove = (text, row, _, action) => {
        return (
            <PremButton
                key='remove'
                pop={{
                    title: '是否删除该客户?',
                    okText: '确认',
                    cancelText: '取消',
                    onConfirm: async () => {
                        let res = await doFetch({ url: urlParams.remove, params: { id: row.id } });
                        if (res.code === '0000') {
                            actionRef.current.reload();
                        }
                    },
                }}
                btn={{
                    size: 'small',
                    type: 'danger',
                }}
            >
                删除
            </PremButton>
        );
    };
    const columns = useMemo(() => {
        let defcolumn = getcolumns(setdrawer)?.columns ?? [];
        return defcolumn.concat({
            title: '操作',
            valueType: 'option',
            width: 150,
            render: (text, row, _, action) => [edit(text, row, _, action), remove(text, row, _, action)],
        });
    }, []);
    const pathconfig = useMemo(() => {
        let pathconf = getcolumns(setdrawer)?.pathconfig ?? {};
        return pathconf;
    }, []);

    return <div>
        <AutoTable
            pagetitle={<h3 className="page-title">客户管理</h3>}
            columns={columns}
            path={pathconfig?.list}
            // dataSource={[{ 'f1': '111', 'f2': '222', id: 1 }]}
            actionRef={actionRef}
            pageextra={'add'}
            resizeable={false}
            addconfig={{
                // access: 'sysDepartment_save',
                btn: {
                    type: 'primary',
                    disabled: false,
                    onClick: () => {
                        // let res = await doFetch({url:})
                        setdrawer((s) => ({
                            ...s,
                            visible: true,
                            item: {},
                            params: {},
                            title: '新增',
                            val: 'add'
                        }));
                    },
                },
            }}
        />
        <DrawerPro
            fields={columns}
            // detailpath={drawer.type == 'add' ? '' : drawer?.detailpath}
            params={{ id: drawer?.item?.id }}
            defaultFormValue={drawer?.item ?? {}}
            detailData={drawer?.item ?? {}}
            placement="right"
            onClose={() => {
                setdrawer((s) => ({
                    ...s,
                    visible: false,
                }));
            }}
            {...drawer}
            onFinish={async (vals) => {
                if (drawer?.val == "add") {
                    await runAsync({ url: pathconfig?.add, params: { ...vals } });
                } else if (drawer?.val == "edit") {
                    await runAsync({
                        url: pathconfig?.edit,
                        params: { ...vals, id: drawer?.item?.id },
                    });
                }
            }}
        >
        </DrawerPro>
    </div>
}
export default Custom;